#include "unicode.h"
#include "offsettbl.h"
struct oft Offset_Table[]={
0x0,0x36F,0,
0x370,0x373,OFT_UNDEF,
0x374,0x375,4,
0x376,0x379,OFT_UNDEF,
0x37A,0x37E,8,
0x37F,0x383,OFT_UNDEF,
0x384,0x38A,13,
0x38B,0x38B,OFT_UNDEF,
0x38C,0x38C,14,
0x38D,0x38D,OFT_UNDEF,
0x38E,0x3A1,15,
0x3A2,0x3A2,OFT_UNDEF,
0x3A3,0x3CE,16,
0x3CF,0x3CF,OFT_UNDEF,
0x3D0,0x486,17,
0x487,0x487,OFT_UNDEF,
0x488,0x513,18,
0x514,0x530,OFT_UNDEF,
0x531,0x556,47,
0x557,0x558,OFT_UNDEF,
0x559,0x55F,49,
0x560,0x560,OFT_UNDEF,
0x561,0x587,50,
0x588,0x588,OFT_UNDEF,
0x589,0x58A,51,
0x58B,0x590,OFT_UNDEF,
0x591,0x5C7,57,
0x5C8,0x5CF,OFT_UNDEF,
0x5D0,0x5EA,65,
0x5EB,0x5EF,OFT_UNDEF,
0x5F0,0x5F4,70,
0x5F5,0x5FF,OFT_UNDEF,
0x600,0x603,81,
0x604,0x60A,OFT_UNDEF,
0x60B,0x615,88,
0x616,0x61A,OFT_UNDEF,
0x61B,0x61B,93,
0x61C,0x61D,OFT_UNDEF,
0x61E,0x61F,95,
0x620,0x620,OFT_UNDEF,
0x621,0x63A,96,
0x63B,0x63F,OFT_UNDEF,
0x640,0x65E,101,
0x65F,0x65F,OFT_UNDEF,
0x660,0x70D,102,
0x70E,0x70E,OFT_UNDEF,
0x70F,0x74A,103,
0x74B,0x74C,OFT_UNDEF,
0x74D,0x76D,105,
0x76E,0x77F,OFT_UNDEF,
0x780,0x7B1,123,
0x7B2,0x7BF,OFT_UNDEF,
0x7C0,0x7FA,137,
0x7FB,0x900,OFT_UNDEF,
0x901,0x939,399,
0x93A,0x93B,OFT_UNDEF,
0x93C,0x94D,401,
0x94E,0x94F,OFT_UNDEF,
0x950,0x954,403,
0x955,0x957,OFT_UNDEF,
0x958,0x970,406,
0x971,0x97A,OFT_UNDEF,
0x97B,0x97F,416,
0x980,0x980,OFT_UNDEF,
0x981,0x983,417,
0x984,0x984,OFT_UNDEF,
0x985,0x98C,418,
0x98D,0x98E,OFT_UNDEF,
0x98F,0x990,420,
0x991,0x992,OFT_UNDEF,
0x993,0x9A8,422,
0x9A9,0x9A9,OFT_UNDEF,
0x9AA,0x9B0,423,
0x9B1,0x9B1,OFT_UNDEF,
0x9B2,0x9B2,424,
0x9B3,0x9B5,OFT_UNDEF,
0x9B6,0x9B9,427,
0x9BA,0x9BB,OFT_UNDEF,
0x9BC,0x9C4,429,
0x9C5,0x9C6,OFT_UNDEF,
0x9C7,0x9C8,431,
0x9C9,0x9CA,OFT_UNDEF,
0x9CB,0x9CE,433,
0x9CF,0x9D6,OFT_UNDEF,
0x9D7,0x9D7,441,
0x9D8,0x9DB,OFT_UNDEF,
0x9DC,0x9DD,445,
0x9DE,0x9DE,OFT_UNDEF,
0x9DF,0x9E3,446,
0x9E4,0x9E5,OFT_UNDEF,
0x9E6,0x9FA,448,
0x9FB,0xA00,OFT_UNDEF,
0xA01,0xA03,454,
0xA04,0xA04,OFT_UNDEF,
0xA05,0xA0A,455,
0xA0B,0xA0E,OFT_UNDEF,
0xA0F,0xA10,459,
0xA11,0xA12,OFT_UNDEF,
0xA13,0xA28,461,
0xA29,0xA29,OFT_UNDEF,
0xA2A,0xA30,462,
0xA31,0xA31,OFT_UNDEF,
0xA32,0xA33,463,
0xA34,0xA34,OFT_UNDEF,
0xA35,0xA36,464,
0xA37,0xA37,OFT_UNDEF,
0xA38,0xA39,465,
0xA3A,0xA3B,OFT_UNDEF,
0xA3C,0xA3C,467,
0xA3D,0xA3D,OFT_UNDEF,
0xA3E,0xA42,468,
0xA43,0xA46,OFT_UNDEF,
0xA47,0xA48,472,
0xA49,0xA4A,OFT_UNDEF,
0xA4B,0xA4D,474,
0xA4E,0xA58,OFT_UNDEF,
0xA59,0xA5C,485,
0xA5D,0xA5D,OFT_UNDEF,
0xA5E,0xA5E,486,
0xA5F,0xA65,OFT_UNDEF,
0xA66,0xA74,493,
0xA75,0xA80,OFT_UNDEF,
0xA81,0xA83,505,
0xA84,0xA84,OFT_UNDEF,
0xA85,0xA8D,506,
0xA8E,0xA8E,OFT_UNDEF,
0xA8F,0xA91,507,
0xA92,0xA92,OFT_UNDEF,
0xA93,0xAA8,508,
0xAA9,0xAA9,OFT_UNDEF,
0xAAA,0xAB0,509,
0xAB1,0xAB1,OFT_UNDEF,
0xAB2,0xAB3,510,
0xAB4,0xAB4,OFT_UNDEF,
0xAB5,0xAB9,511,
0xABA,0xABB,OFT_UNDEF,
0xABC,0xAC5,513,
0xAC6,0xAC6,OFT_UNDEF,
0xAC7,0xAC9,514,
0xACA,0xACA,OFT_UNDEF,
0xACB,0xACD,515,
0xACE,0xACF,OFT_UNDEF,
0xAD0,0xAD0,517,
0xAD1,0xADF,OFT_UNDEF,
0xAE0,0xAE3,532,
0xAE4,0xAE5,OFT_UNDEF,
0xAE6,0xAEF,534,
0xAF0,0xAF0,OFT_UNDEF,
0xAF1,0xAF1,535,
0xAF2,0xB00,OFT_UNDEF,
0xB01,0xB03,550,
0xB04,0xB04,OFT_UNDEF,
0xB05,0xB0C,551,
0xB0D,0xB0E,OFT_UNDEF,
0xB0F,0xB10,553,
0xB11,0xB12,OFT_UNDEF,
0xB13,0xB28,555,
0xB29,0xB29,OFT_UNDEF,
0xB2A,0xB30,556,
0xB31,0xB31,OFT_UNDEF,
0xB32,0xB33,557,
0xB34,0xB34,OFT_UNDEF,
0xB35,0xB39,558,
0xB3A,0xB3B,OFT_UNDEF,
0xB3C,0xB43,560,
0xB44,0xB46,OFT_UNDEF,
0xB47,0xB48,563,
0xB49,0xB4A,OFT_UNDEF,
0xB4B,0xB4D,565,
0xB4E,0xB55,OFT_UNDEF,
0xB56,0xB57,573,
0xB58,0xB5B,OFT_UNDEF,
0xB5C,0xB5D,577,
0xB5E,0xB5E,OFT_UNDEF,
0xB5F,0xB61,578,
0xB62,0xB65,OFT_UNDEF,
0xB66,0xB71,582,
0xB72,0xB81,OFT_UNDEF,
0xB82,0xB83,598,
0xB84,0xB84,OFT_UNDEF,
0xB85,0xB8A,599,
0xB8B,0xB8D,OFT_UNDEF,
0xB8E,0xB90,602,
0xB91,0xB91,OFT_UNDEF,
0xB92,0xB95,603,
0xB96,0xB98,OFT_UNDEF,
0xB99,0xB9A,606,
0xB9B,0xB9B,OFT_UNDEF,
0xB9C,0xB9C,607,
0xB9D,0xB9D,OFT_UNDEF,
0xB9E,0xB9F,608,
0xBA0,0xBA2,OFT_UNDEF,
0xBA3,0xBA4,611,
0xBA5,0xBA7,OFT_UNDEF,
0xBA8,0xBAA,614,
0xBAB,0xBAD,OFT_UNDEF,
0xBAE,0xBB9,617,
0xBBA,0xBBD,OFT_UNDEF,
0xBBE,0xBC2,621,
0xBC3,0xBC5,OFT_UNDEF,
0xBC6,0xBC8,624,
0xBC9,0xBC9,OFT_UNDEF,
0xBCA,0xBCD,625,
0xBCE,0xBD6,OFT_UNDEF,
0xBD7,0xBD7,634,
0xBD8,0xBE5,OFT_UNDEF,
0xBE6,0xBFA,648,
0xBFB,0xC00,OFT_UNDEF,
0xC01,0xC03,654,
0xC04,0xC04,OFT_UNDEF,
0xC05,0xC0C,655,
0xC0D,0xC0D,OFT_UNDEF,
0xC0E,0xC10,656,
0xC11,0xC11,OFT_UNDEF,
0xC12,0xC28,657,
0xC29,0xC29,OFT_UNDEF,
0xC2A,0xC33,658,
0xC34,0xC34,OFT_UNDEF,
0xC35,0xC39,659,
0xC3A,0xC3D,OFT_UNDEF,
0xC3E,0xC44,663,
0xC45,0xC45,OFT_UNDEF,
0xC46,0xC48,664,
0xC49,0xC49,OFT_UNDEF,
0xC4A,0xC4D,665,
0xC4E,0xC54,OFT_UNDEF,
0xC55,0xC56,672,
0xC57,0xC5F,OFT_UNDEF,
0xC60,0xC61,681,
0xC62,0xC65,OFT_UNDEF,
0xC66,0xC6F,685,
0xC70,0xC81,OFT_UNDEF,
0xC82,0xC83,703,
0xC84,0xC84,OFT_UNDEF,
0xC85,0xC8C,704,
0xC8D,0xC8D,OFT_UNDEF,
0xC8E,0xC90,705,
0xC91,0xC91,OFT_UNDEF,
0xC92,0xCA8,706,
0xCA9,0xCA9,OFT_UNDEF,
0xCAA,0xCB3,707,
0xCB4,0xCB4,OFT_UNDEF,
0xCB5,0xCB9,708,
0xCBA,0xCBB,OFT_UNDEF,
0xCBC,0xCC4,710,
0xCC5,0xCC5,OFT_UNDEF,
0xCC6,0xCC8,711,
0xCC9,0xCC9,OFT_UNDEF,
0xCCA,0xCCD,712,
0xCCE,0xCD4,OFT_UNDEF,
0xCD5,0xCD6,719,
0xCD7,0xCDD,OFT_UNDEF,
0xCDE,0xCDE,726,
0xCDF,0xCDF,OFT_UNDEF,
0xCE0,0xCE3,727,
0xCE4,0xCE5,OFT_UNDEF,
0xCE6,0xCEF,729,
0xCF0,0xCF0,OFT_UNDEF,
0xCF1,0xCF2,730,
0xCF3,0xD01,OFT_UNDEF,
0xD02,0xD03,745,
0xD04,0xD04,OFT_UNDEF,
0xD05,0xD0C,746,
0xD0D,0xD0D,OFT_UNDEF,
0xD0E,0xD10,747,
0xD11,0xD11,OFT_UNDEF,
0xD12,0xD28,748,
0xD29,0xD29,OFT_UNDEF,
0xD2A,0xD39,749,
0xD3A,0xD3D,OFT_UNDEF,
0xD3E,0xD43,753,
0xD44,0xD45,OFT_UNDEF,
0xD46,0xD48,755,
0xD49,0xD49,OFT_UNDEF,
0xD4A,0xD4D,756,
0xD4E,0xD56,OFT_UNDEF,
0xD57,0xD57,765,
0xD58,0xD5F,OFT_UNDEF,
0xD60,0xD61,773,
0xD62,0xD65,OFT_UNDEF,
0xD66,0xD6F,777,
0xD70,0xD81,OFT_UNDEF,
0xD82,0xD83,795,
0xD84,0xD84,OFT_UNDEF,
0xD85,0xD96,796,
0xD97,0xD99,OFT_UNDEF,
0xD9A,0xDB1,799,
0xDB2,0xDB2,OFT_UNDEF,
0xDB3,0xDBB,800,
0xDBC,0xDBC,OFT_UNDEF,
0xDBD,0xDBD,801,
0xDBE,0xDBF,OFT_UNDEF,
0xDC0,0xDC6,803,
0xDC7,0xDC9,OFT_UNDEF,
0xDCA,0xDCA,806,
0xDCB,0xDCE,OFT_UNDEF,
0xDCF,0xDD4,810,
0xDD5,0xDD5,OFT_UNDEF,
0xDD6,0xDD6,811,
0xDD7,0xDD7,OFT_UNDEF,
0xDD8,0xDDF,812,
0xDE0,0xDF1,OFT_UNDEF,
0xDF2,0xDF4,830,
0xDF5,0xE00,OFT_UNDEF,
0xE01,0xE3A,842,
0xE3B,0xE3E,OFT_UNDEF,
0xE3F,0xE5B,846,
0xE5C,0xE80,OFT_UNDEF,
0xE81,0xE82,883,
0xE83,0xE83,OFT_UNDEF,
0xE84,0xE84,884,
0xE85,0xE86,OFT_UNDEF,
0xE87,0xE88,886,
0xE89,0xE89,OFT_UNDEF,
0xE8A,0xE8A,887,
0xE8B,0xE8C,OFT_UNDEF,
0xE8D,0xE8D,889,
0xE8E,0xE93,OFT_UNDEF,
0xE94,0xE97,895,
0xE98,0xE98,OFT_UNDEF,
0xE99,0xE9F,896,
0xEA0,0xEA0,OFT_UNDEF,
0xEA1,0xEA3,897,
0xEA4,0xEA4,OFT_UNDEF,
0xEA5,0xEA5,898,
0xEA6,0xEA6,OFT_UNDEF,
0xEA7,0xEA7,899,
0xEA8,0xEA9,OFT_UNDEF,
0xEAA,0xEAB,901,
0xEAC,0xEAC,OFT_UNDEF,
0xEAD,0xEB9,902,
0xEBA,0xEBA,OFT_UNDEF,
0xEBB,0xEBD,903,
0xEBE,0xEBF,OFT_UNDEF,
0xEC0,0xEC4,905,
0xEC5,0xEC5,OFT_UNDEF,
0xEC6,0xEC6,906,
0xEC7,0xEC7,OFT_UNDEF,
0xEC8,0xECD,907,
0xECE,0xECF,OFT_UNDEF,
0xED0,0xED9,909,
0xEDA,0xEDB,OFT_UNDEF,
0xEDC,0xEDD,911,
0xEDE,0xEFF,OFT_UNDEF,
0xF00,0xF47,945,
0xF48,0xF48,OFT_UNDEF,
0xF49,0xF6A,946,
0xF6B,0xF70,OFT_UNDEF,
0xF71,0xF8B,952,
0xF8C,0xF8F,OFT_UNDEF,
0xF90,0xF97,956,
0xF98,0xF98,OFT_UNDEF,
0xF99,0xFBC,957,
0xFBD,0xFBD,OFT_UNDEF,
0xFBE,0xFCC,958,
0xFCD,0xFCE,OFT_UNDEF,
0xFCF,0xFD1,960,
0xFD2,0xFFF,OFT_UNDEF,
0x1000,0x1021,1006,
0x1022,0x1022,OFT_UNDEF,
0x1023,0x1027,1007,
0x1028,0x1028,OFT_UNDEF,
0x1029,0x102A,1008,
0x102B,0x102B,OFT_UNDEF,
0x102C,0x1032,1009,
0x1033,0x1035,OFT_UNDEF,
0x1036,0x1039,1012,
0x103A,0x103F,OFT_UNDEF,
0x1040,0x1059,1018,
0x105A,0x109F,OFT_UNDEF,
0x10A0,0x10C5,1088,
0x10C6,0x10CF,OFT_UNDEF,
0x10D0,0x10FC,1098,
0x10FD,0x10FF,OFT_UNDEF,
0x1100,0x1159,1101,
0x115A,0x115E,OFT_UNDEF,
0x115F,0x11A2,1106,
0x11A3,0x11A7,OFT_UNDEF,
0x11A8,0x11F9,1111,
0x11FA,0x11FF,OFT_UNDEF,
0x1200,0x1248,1117,
0x1249,0x1249,OFT_UNDEF,
0x124A,0x124D,1118,
0x124E,0x124F,OFT_UNDEF,
0x1250,0x1256,1120,
0x1257,0x1257,OFT_UNDEF,
0x1258,0x1258,1121,
0x1259,0x1259,OFT_UNDEF,
0x125A,0x125D,1122,
0x125E,0x125F,OFT_UNDEF,
0x1260,0x1288,1124,
0x1289,0x1289,OFT_UNDEF,
0x128A,0x128D,1125,
0x128E,0x128F,OFT_UNDEF,
0x1290,0x12B0,1127,
0x12B1,0x12B1,OFT_UNDEF,
0x12B2,0x12B5,1128,
0x12B6,0x12B7,OFT_UNDEF,
0x12B8,0x12BE,1130,
0x12BF,0x12BF,OFT_UNDEF,
0x12C0,0x12C0,1131,
0x12C1,0x12C1,OFT_UNDEF,
0x12C2,0x12C5,1132,
0x12C6,0x12C7,OFT_UNDEF,
0x12C8,0x12D6,1134,
0x12D7,0x12D7,OFT_UNDEF,
0x12D8,0x1310,1135,
0x1311,0x1311,OFT_UNDEF,
0x1312,0x1315,1136,
0x1316,0x1317,OFT_UNDEF,
0x1318,0x135A,1138,
0x135B,0x135E,OFT_UNDEF,
0x135F,0x137C,1142,
0x137D,0x137F,OFT_UNDEF,
0x1380,0x1399,1145,
0x139A,0x139F,OFT_UNDEF,
0x13A0,0x13F4,1151,
0x13F5,0x1400,OFT_UNDEF,
0x1401,0x1676,1163,
0x1677,0x167F,OFT_UNDEF,
0x1680,0x169C,1172,
0x169D,0x169F,OFT_UNDEF,
0x16A0,0x16F0,1175,
0x16F1,0x16FF,OFT_UNDEF,
0x1700,0x170C,1190,
0x170D,0x170D,OFT_UNDEF,
0x170E,0x1714,1191,
0x1715,0x171F,OFT_UNDEF,
0x1720,0x1736,1202,
0x1737,0x173F,OFT_UNDEF,
0x1740,0x1753,1211,
0x1754,0x175F,OFT_UNDEF,
0x1760,0x176C,1223,
0x176D,0x176D,OFT_UNDEF,
0x176E,0x1770,1224,
0x1771,0x1771,OFT_UNDEF,
0x1772,0x1773,1225,
0x1774,0x177F,OFT_UNDEF,
0x1780,0x17DD,1237,
0x17DE,0x17DF,OFT_UNDEF,
0x17E0,0x17E9,1239,
0x17EA,0x17EF,OFT_UNDEF,
0x17F0,0x17F9,1245,
0x17FA,0x17FF,OFT_UNDEF,
0x1800,0x180E,1251,
0x180F,0x180F,OFT_UNDEF,
0x1810,0x1819,1252,
0x181A,0x181F,OFT_UNDEF,
0x1820,0x1877,1258,
0x1878,0x187F,OFT_UNDEF,
0x1880,0x18A9,1266,
0x18AA,0x18FF,OFT_UNDEF,
0x1900,0x191C,1352,
0x191D,0x191F,OFT_UNDEF,
0x1920,0x192B,1355,
0x192C,0x192F,OFT_UNDEF,
0x1930,0x193B,1359,
0x193C,0x193F,OFT_UNDEF,
0x1940,0x1940,1363,
0x1941,0x1943,OFT_UNDEF,
0x1944,0x196D,1366,
0x196E,0x196F,OFT_UNDEF,
0x1970,0x1974,1368,
0x1975,0x197F,OFT_UNDEF,
0x1980,0x19A9,1379,
0x19AA,0x19AF,OFT_UNDEF,
0x19B0,0x19C9,1385,
0x19CA,0x19CF,OFT_UNDEF,
0x19D0,0x19D9,1391,
0x19DA,0x19DD,OFT_UNDEF,
0x19DE,0x1A1B,1395,
0x1A1C,0x1A1D,OFT_UNDEF,
0x1A1E,0x1A1F,1397,
0x1A20,0x1AFF,OFT_UNDEF,
0x1B00,0x1B4B,1621,
0x1B4C,0x1B4F,OFT_UNDEF,
0x1B50,0x1B7C,1625,
0x1B7D,0x1CFF,OFT_UNDEF,
0x1D00,0x1DCA,2012,
0x1DCB,0x1DFD,OFT_UNDEF,
0x1DFE,0x1E9B,2063,
0x1E9C,0x1E9F,OFT_UNDEF,
0x1EA0,0x1EF9,2067,
0x1EFA,0x1EFF,OFT_UNDEF,
0x1F00,0x1F15,2073,
0x1F16,0x1F17,OFT_UNDEF,
0x1F18,0x1F1D,2075,
0x1F1E,0x1F1F,OFT_UNDEF,
0x1F20,0x1F45,2077,
0x1F46,0x1F47,OFT_UNDEF,
0x1F48,0x1F4D,2079,
0x1F4E,0x1F4F,OFT_UNDEF,
0x1F50,0x1F57,2081,
0x1F58,0x1F58,OFT_UNDEF,
0x1F59,0x1F59,2082,
0x1F5A,0x1F5A,OFT_UNDEF,
0x1F5B,0x1F5B,2083,
0x1F5C,0x1F5C,OFT_UNDEF,
0x1F5D,0x1F5D,2084,
0x1F5E,0x1F5E,OFT_UNDEF,
0x1F5F,0x1F7D,2085,
0x1F7E,0x1F7F,OFT_UNDEF,
0x1F80,0x1FB4,2087,
0x1FB5,0x1FB5,OFT_UNDEF,
0x1FB6,0x1FC4,2088,
0x1FC5,0x1FC5,OFT_UNDEF,
0x1FC6,0x1FD3,2089,
0x1FD4,0x1FD5,OFT_UNDEF,
0x1FD6,0x1FDB,2091,
0x1FDC,0x1FDC,OFT_UNDEF,
0x1FDD,0x1FEF,2092,
0x1FF0,0x1FF1,OFT_UNDEF,
0x1FF2,0x1FF4,2094,
0x1FF5,0x1FF5,OFT_UNDEF,
0x1FF6,0x1FFE,2095,
0x1FFF,0x1FFF,OFT_UNDEF,
0x2000,0x2063,2096,
0x2064,0x2069,OFT_UNDEF,
0x206A,0x2071,2102,
0x2072,0x2073,OFT_UNDEF,
0x2074,0x208E,2104,
0x208F,0x208F,OFT_UNDEF,
0x2090,0x2094,2105,
0x2095,0x209F,OFT_UNDEF,
0x20A0,0x20B5,2116,
0x20B6,0x20CF,OFT_UNDEF,
0x20D0,0x20EF,2142,
0x20F0,0x20FF,OFT_UNDEF,
0x2100,0x214E,2158,
0x214F,0x2152,OFT_UNDEF,
0x2153,0x2184,2162,
0x2185,0x218F,OFT_UNDEF,
0x2190,0x23E7,2173,
0x23E8,0x23FF,OFT_UNDEF,
0x2400,0x2426,2197,
0x2427,0x243F,OFT_UNDEF,
0x2440,0x244A,2222,
0x244B,0x245F,OFT_UNDEF,
0x2460,0x269C,2243,
0x269D,0x269F,OFT_UNDEF,
0x26A0,0x26B2,2246,
0x26B3,0x2700,OFT_UNDEF,
0x2701,0x2704,2324,
0x2705,0x2705,OFT_UNDEF,
0x2706,0x2709,2325,
0x270A,0x270B,OFT_UNDEF,
0x270C,0x2727,2327,
0x2728,0x2728,OFT_UNDEF,
0x2729,0x274B,2328,
0x274C,0x274C,OFT_UNDEF,
0x274D,0x274D,2329,
0x274E,0x274E,OFT_UNDEF,
0x274F,0x2752,2330,
0x2753,0x2755,OFT_UNDEF,
0x2756,0x2756,2333,
0x2757,0x2757,OFT_UNDEF,
0x2758,0x275E,2334,
0x275F,0x2760,OFT_UNDEF,
0x2761,0x2794,2336,
0x2795,0x2797,OFT_UNDEF,
0x2798,0x27AF,2339,
0x27B0,0x27B0,OFT_UNDEF,
0x27B1,0x27BE,2340,
0x27BF,0x27BF,OFT_UNDEF,
0x27C0,0x27CA,2341,
0x27CB,0x27CF,OFT_UNDEF,
0x27D0,0x27EB,2346,
0x27EC,0x27EF,OFT_UNDEF,
0x27F0,0x2B1A,2350,
0x2B1B,0x2B1F,OFT_UNDEF,
0x2B20,0x2B23,2355,
0x2B24,0x2BFF,OFT_UNDEF,
0x2C00,0x2C2E,2575,
0x2C2F,0x2C2F,OFT_UNDEF,
0x2C30,0x2C5E,2576,
0x2C5F,0x2C5F,OFT_UNDEF,
0x2C60,0x2C6C,2577,
0x2C6D,0x2C73,OFT_UNDEF,
0x2C74,0x2C77,2584,
0x2C78,0x2C7F,OFT_UNDEF,
0x2C80,0x2CEA,2592,
0x2CEB,0x2CF8,OFT_UNDEF,
0x2CF9,0x2D25,2606,
0x2D26,0x2D2F,OFT_UNDEF,
0x2D30,0x2D65,2616,
0x2D66,0x2D6E,OFT_UNDEF,
0x2D6F,0x2D6F,2625,
0x2D70,0x2D7F,OFT_UNDEF,
0x2D80,0x2D96,2641,
0x2D97,0x2D9F,OFT_UNDEF,
0x2DA0,0x2DA6,2650,
0x2DA7,0x2DA7,OFT_UNDEF,
0x2DA8,0x2DAE,2651,
0x2DAF,0x2DAF,OFT_UNDEF,
0x2DB0,0x2DB6,2652,
0x2DB7,0x2DB7,OFT_UNDEF,
0x2DB8,0x2DBE,2653,
0x2DBF,0x2DBF,OFT_UNDEF,
0x2DC0,0x2DC6,2654,
0x2DC7,0x2DC7,OFT_UNDEF,
0x2DC8,0x2DCE,2655,
0x2DCF,0x2DCF,OFT_UNDEF,
0x2DD0,0x2DD6,2656,
0x2DD7,0x2DD7,OFT_UNDEF,
0x2DD8,0x2DDE,2657,
0x2DDF,0x2DFF,OFT_UNDEF,
0x2E00,0x2E17,2690,
0x2E18,0x2E1B,OFT_UNDEF,
0x2E1C,0x2E1D,2694,
0x2E1E,0x2E7F,OFT_UNDEF,
0x2E80,0x2E99,2792,
0x2E9A,0x2E9A,OFT_UNDEF,
0x2E9B,0x2EF3,2793,
0x2EF4,0x2EFF,OFT_UNDEF,
0x2F00,0x2FD5,2805,
0x2FD6,0x2FEF,OFT_UNDEF,
0x2FF0,0x2FFB,2831,
0x2FFC,0x2FFF,OFT_UNDEF,
0x3000,0x303F,2835,
0x3040,0x3040,OFT_UNDEF,
0x3041,0x3096,2836,
0x3097,0x3098,OFT_UNDEF,
0x3099,0x30FF,2838,
0x3100,0x3104,OFT_UNDEF,
0x3105,0x312C,2843,
0x312D,0x3130,OFT_UNDEF,
0x3131,0x318E,2847,
0x318F,0x318F,OFT_UNDEF,
0x3190,0x31B7,2848,
0x31B8,0x31BF,OFT_UNDEF,
0x31C0,0x31CF,2856,
0x31D0,0x31EF,OFT_UNDEF,
0x31F0,0x321E,2888,
0x321F,0x321F,OFT_UNDEF,
0x3220,0x3243,2889,
0x3244,0x324F,OFT_UNDEF,
0x3250,0x32FE,2901,
0x32FF,0x32FF,OFT_UNDEF,
0x3300,0x33FF,2902,
0x3400,0x4DB5,OFT_NOINF,
0x4DB6,0x4DBF,OFT_UNDEF,
0x4DC0,0x4DFF,9494,
0x4E00,0x9FBB,OFT_NOINF,
0x9FBC,0x9FFF,OFT_UNDEF,
0xA000,0xA48C,30486,
0xA48D,0xA48F,OFT_UNDEF,
0xA490,0xA4C6,30489,
0xA4C7,0xA6FF,OFT_UNDEF,
0xA700,0xA71A,31058,
0xA71B,0xA71F,OFT_UNDEF,
0xA720,0xA721,31063,
0xA722,0xA7FF,OFT_UNDEF,
0xA800,0xA82B,31285,
0xA82C,0xA83F,OFT_UNDEF,
0xA840,0xA877,31305,
0xA878,0xABFF,OFT_UNDEF,
0xAC00,0xD7A3,OFT_NOINF,
0xD7A4,0xD7FF,OFT_UNDEF,
0xD800,0xDB7F,OFT_NOINF,
0xDB80,0xDBFF,OFT_NOINF,
0xDC00,0xDFFF,OFT_NOINF,
0xE000,0xF8FF,OFT_NOINF,
0xF900,0xFA2D,51921,
0xFA2E,0xFA2F,OFT_UNDEF,
0xFA30,0xFA6A,51923,
0xFA6B,0xFA6F,OFT_UNDEF,
0xFA70,0xFAD9,51928,
0xFADA,0xFAFF,OFT_UNDEF,
0xFB00,0xFB06,51966,
0xFB07,0xFB12,OFT_UNDEF,
0xFB13,0xFB17,51978,
0xFB18,0xFB1C,OFT_UNDEF,
0xFB1D,0xFB36,51983,
0xFB37,0xFB37,OFT_UNDEF,
0xFB38,0xFB3C,51984,
0xFB3D,0xFB3D,OFT_UNDEF,
0xFB3E,0xFB3E,51985,
0xFB3F,0xFB3F,OFT_UNDEF,
0xFB40,0xFB41,51986,
0xFB42,0xFB42,OFT_UNDEF,
0xFB43,0xFB44,51987,
0xFB45,0xFB45,OFT_UNDEF,
0xFB46,0xFBB1,51988,
0xFBB2,0xFBD2,OFT_UNDEF,
0xFBD3,0xFD3F,52021,
0xFD40,0xFD4F,OFT_UNDEF,
0xFD50,0xFD8F,52037,
0xFD90,0xFD91,OFT_UNDEF,
0xFD92,0xFDC7,52039,
0xFDC8,0xFDEF,OFT_UNDEF,
0xFDF0,0xFDFD,52079,
0xFDFE,0xFDFF,OFT_UNDEF,
0xFE00,0xFE19,52081,
0xFE1A,0xFE1F,OFT_UNDEF,
0xFE20,0xFE23,52087,
0xFE24,0xFE2F,OFT_UNDEF,
0xFE30,0xFE52,52099,
0xFE53,0xFE53,OFT_UNDEF,
0xFE54,0xFE66,52100,
0xFE67,0xFE67,OFT_UNDEF,
0xFE68,0xFE6B,52101,
0xFE6C,0xFE6F,OFT_UNDEF,
0xFE70,0xFE74,52105,
0xFE75,0xFE75,OFT_UNDEF,
0xFE76,0xFEFC,52106,
0xFEFD,0xFEFE,OFT_UNDEF,
0xFEFF,0xFEFF,52108,
0xFF00,0xFF00,OFT_UNDEF,
0xFF01,0xFFBE,52109,
0xFFBF,0xFFC1,OFT_UNDEF,
0xFFC2,0xFFC7,52112,
0xFFC8,0xFFC9,OFT_UNDEF,
0xFFCA,0xFFCF,52114,
0xFFD0,0xFFD1,OFT_UNDEF,
0xFFD2,0xFFD7,52116,
0xFFD8,0xFFD9,OFT_UNDEF,
0xFFDA,0xFFDC,52118,
0xFFDD,0xFFDF,OFT_UNDEF,
0xFFE0,0xFFE6,52121,
0xFFE7,0xFFE7,OFT_UNDEF,
0xFFE8,0xFFEE,52122,
0xFFEF,0xFFF8,OFT_UNDEF,
0xFFF9,0xFFFD,52132,
0xFFFE,0xFFFF,OFT_UNDEF,
0x10000,0x1000B,52134,
0x1000C,0x1000C,OFT_UNDEF,
0x1000D,0x10026,52135,
0x10027,0x10027,OFT_UNDEF,
0x10028,0x1003A,52136,
0x1003B,0x1003B,OFT_UNDEF,
0x1003C,0x1003D,52137,
0x1003E,0x1003E,OFT_UNDEF,
0x1003F,0x1004D,52138,
0x1004E,0x1004F,OFT_UNDEF,
0x10050,0x1005D,52140,
0x1005E,0x1007F,OFT_UNDEF,
0x10080,0x100FA,52174,
0x100FB,0x100FF,OFT_UNDEF,
0x10100,0x10102,52179,
0x10103,0x10106,OFT_UNDEF,
0x10107,0x10133,52183,
0x10134,0x10136,OFT_UNDEF,
0x10137,0x1018A,52186,
0x1018B,0x102FF,OFT_UNDEF,
0x10300,0x1031E,52559,
0x1031F,0x1031F,OFT_UNDEF,
0x10320,0x10323,52560,
0x10324,0x1032F,OFT_UNDEF,
0x10330,0x1034A,52572,
0x1034B,0x1037F,OFT_UNDEF,
0x10380,0x1039D,52625,
0x1039E,0x1039E,OFT_UNDEF,
0x1039F,0x103C3,52626,
0x103C4,0x103C7,OFT_UNDEF,
0x103C8,0x103D5,52630,
0x103D6,0x103FF,OFT_UNDEF,
0x10400,0x1049D,52672,
0x1049E,0x1049F,OFT_UNDEF,
0x104A0,0x104A9,52674,
0x104AA,0x107FF,OFT_UNDEF,
0x10800,0x10805,53528,
0x10806,0x10807,OFT_UNDEF,
0x10808,0x10808,53530,
0x10809,0x10809,OFT_UNDEF,
0x1080A,0x10835,53531,
0x10836,0x10836,OFT_UNDEF,
0x10837,0x10838,53532,
0x10839,0x1083B,OFT_UNDEF,
0x1083C,0x1083C,53535,
0x1083D,0x1083E,OFT_UNDEF,
0x1083F,0x1083F,53537,
0x10840,0x108FF,OFT_UNDEF,
0x10900,0x10919,53729,
0x1091A,0x1091E,OFT_UNDEF,
0x1091F,0x1091F,53734,
0x10920,0x109FF,OFT_UNDEF,
0x10A00,0x10A03,53958,
0x10A04,0x10A04,OFT_UNDEF,
0x10A05,0x10A06,53959,
0x10A07,0x10A0B,OFT_UNDEF,
0x10A0C,0x10A13,53964,
0x10A14,0x10A14,OFT_UNDEF,
0x10A15,0x10A17,53965,
0x10A18,0x10A18,OFT_UNDEF,
0x10A19,0x10A33,53966,
0x10A34,0x10A37,OFT_UNDEF,
0x10A38,0x10A3A,53970,
0x10A3B,0x10A3E,OFT_UNDEF,
0x10A3F,0x10A47,53974,
0x10A48,0x10A4F,OFT_UNDEF,
0x10A50,0x10A58,53982,
0x10A59,0x11FFF,OFT_UNDEF,
0x12000,0x1236E,59525,
0x1236F,0x123FF,OFT_UNDEF,
0x12400,0x12462,59670,
0x12463,0x1246F,OFT_UNDEF,
0x12470,0x12473,59683,
0x12474,0x1CFFF,OFT_UNDEF,
0x1D000,0x1D0F5,103599,
0x1D0F6,0x1D0FF,OFT_UNDEF,
0x1D100,0x1D126,103609,
0x1D127,0x1D129,OFT_UNDEF,
0x1D12A,0x1D1DD,103612,
0x1D1DE,0x1D1FF,OFT_UNDEF,
0x1D200,0x1D245,103646,
0x1D246,0x1D2FF,OFT_UNDEF,
0x1D300,0x1D356,103832,
0x1D357,0x1D35F,OFT_UNDEF,
0x1D360,0x1D371,103841,
0x1D372,0x1D3FF,OFT_UNDEF,
0x1D400,0x1D454,103983,
0x1D455,0x1D455,OFT_UNDEF,
0x1D456,0x1D49C,103984,
0x1D49D,0x1D49D,OFT_UNDEF,
0x1D49E,0x1D49F,103985,
0x1D4A0,0x1D4A1,OFT_UNDEF,
0x1D4A2,0x1D4A2,103987,
0x1D4A3,0x1D4A4,OFT_UNDEF,
0x1D4A5,0x1D4A6,103989,
0x1D4A7,0x1D4A8,OFT_UNDEF,
0x1D4A9,0x1D4AC,103991,
0x1D4AD,0x1D4AD,OFT_UNDEF,
0x1D4AE,0x1D4B9,103992,
0x1D4BA,0x1D4BA,OFT_UNDEF,
0x1D4BB,0x1D4BB,103993,
0x1D4BC,0x1D4BC,OFT_UNDEF,
0x1D4BD,0x1D4C3,103994,
0x1D4C4,0x1D4C4,OFT_UNDEF,
0x1D4C5,0x1D505,103995,
0x1D506,0x1D506,OFT_UNDEF,
0x1D507,0x1D50A,103996,
0x1D50B,0x1D50C,OFT_UNDEF,
0x1D50D,0x1D514,103998,
0x1D515,0x1D515,OFT_UNDEF,
0x1D516,0x1D51C,103999,
0x1D51D,0x1D51D,OFT_UNDEF,
0x1D51E,0x1D539,104000,
0x1D53A,0x1D53A,OFT_UNDEF,
0x1D53B,0x1D53E,104001,
0x1D53F,0x1D53F,OFT_UNDEF,
0x1D540,0x1D544,104002,
0x1D545,0x1D545,OFT_UNDEF,
0x1D546,0x1D546,104003,
0x1D547,0x1D549,OFT_UNDEF,
0x1D54A,0x1D550,104006,
0x1D551,0x1D551,OFT_UNDEF,
0x1D552,0x1D6A5,104007,
0x1D6A6,0x1D6A7,OFT_UNDEF,
0x1D6A8,0x1D7CB,104009,
0x1D7CC,0x1D7CD,OFT_UNDEF,
0x1D7CE,0x1D7FF,104011,
0x1D800,0x1FFFF,OFT_UNDEF,
0x20000,0x2A6D6,OFT_NOINF,
0x2A6D7,0x2F7FF,OFT_UNDEF,
0x2F800,0x2FA1D,177739,
0x2FA1E,0xE0000,OFT_UNDEF,
0xE0001,0xE0001,900142,
0xE0002,0xE001F,OFT_UNDEF,
0xE0020,0xE007F,900172,
0xE0080,0xE00FF,OFT_UNDEF,
0xE0100,0xE01EF,900300,
0xE01F0,0xEFFFF,OFT_UNDEF,
0xF0000,0xFFFFD,OFT_NOINF,
0xFFFFE,0xFFFFF,OFT_UNDEF,
0x100000,0x10FFFF,OFT_NOINF,
};
int Offset_Entries = sizeof(Offset_Table)/sizeof(struct oft);
